==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/MooreActionHomeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHome;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineStateSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MooreStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineStateSetImpl;

import java.util.Arrays;
import java.util.List;


public class MooreActionHomeSetImpl extends InstanceSet<MooreActionHomeSet,MooreActionHome> implements MooreActionHomeSet {

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( MooreActionHome mooreactionhome : this ) mooreactionhome.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setAct_ID( UniqueId ref_Act_ID ) throws XtumlException {
        for ( MooreActionHome mooreactionhome : this ) mooreactionhome.setAct_ID( ref_Act_ID );
    }
    @Override
    public void setSMstt_ID( UniqueId ref_SMstt_ID ) throws XtumlException {
        for ( MooreActionHome mooreactionhome : this ) mooreactionhome.setSMstt_ID( ref_SMstt_ID );
    }


    // selections
    @Override
    public MooreStateMachineSet R511_MooreStateMachine() throws XtumlException {
        MooreStateMachineSet moorestatemachineset = new MooreStateMachineSetImpl();
        for ( MooreActionHome mooreactionhome : this ) moorestatemachineset.add( mooreactionhome.R511_MooreStateMachine() );
        return moorestatemachineset;
    }
    @Override
    public StateMachineStateSet R511_StateMachineState() throws XtumlException {
        StateMachineStateSet statemachinestateset = new StateMachineStateSetImpl();
        for ( MooreActionHome mooreactionhome : this ) statemachinestateset.add( mooreactionhome.R511_StateMachineState() );
        return statemachinestateset;
    }
    @Override
    public ActionHomeSet R513_is_a_ActionHome() throws XtumlException {
        ActionHomeSet actionhomeset = new ActionHomeSetImpl();
        for ( MooreActionHome mooreactionhome : this ) actionhomeset.add( mooreactionhome.R513_is_a_ActionHome() );
        return actionhomeset;
    }


    @Override
    public MooreActionHome nullElement() {
        return MooreActionHomeImpl.EMPTY_MOOREACTIONHOME;
    }

    @Override
    public MooreActionHomeSet emptySet() {
      return new MooreActionHomeSetImpl();
    }

    @Override
    public MooreActionHomeSet value() {
        return this;
    }

    @Override
    public List<MooreActionHome> elements() {
        return Arrays.asList(toArray(new MooreActionHome[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/MooreActionHomeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHome;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineStateSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MooreStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineStateSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class MooreActionHomeSetImpl extends InstanceSet<MooreActionHomeSet,MooreActionHome> implements MooreActionHomeSet {

    public MooreActionHomeSetImpl() {
    }

    public MooreActionHomeSetImpl(Comparator<? super MooreActionHome> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSMstt_ID( UniqueId ref_SMstt_ID ) throws XtumlException {
        for ( MooreActionHome mooreactionhome : this ) mooreactionhome.setSMstt_ID( ref_SMstt_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( MooreActionHome mooreactionhome : this ) mooreactionhome.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setAct_ID( UniqueId ref_Act_ID ) throws XtumlException {
        for ( MooreActionHome mooreactionhome : this ) mooreactionhome.setAct_ID( ref_Act_ID );
    }


    // selections
    @Override
    public MooreStateMachineSet R511_MooreStateMachine() throws XtumlException {
        MooreStateMachineSet moorestatemachineset = new MooreStateMachineSetImpl();
        for ( MooreActionHome mooreactionhome : this ) moorestatemachineset.add( mooreactionhome.R511_MooreStateMachine() );
        return moorestatemachineset;
    }
    @Override
    public StateMachineStateSet R511_StateMachineState() throws XtumlException {
        StateMachineStateSet statemachinestateset = new StateMachineStateSetImpl();
        for ( MooreActionHome mooreactionhome : this ) statemachinestateset.add( mooreactionhome.R511_StateMachineState() );
        return statemachinestateset;
    }
    @Override
    public ActionHomeSet R513_is_a_ActionHome() throws XtumlException {
        ActionHomeSet actionhomeset = new ActionHomeSetImpl();
        for ( MooreActionHome mooreactionhome : this ) actionhomeset.add( mooreactionhome.R513_is_a_ActionHome() );
        return actionhomeset;
    }


    @Override
    public MooreActionHome nullElement() {
        return MooreActionHomeImpl.EMPTY_MOOREACTIONHOME;
    }

    @Override
    public MooreActionHomeSet emptySet() {
      return new MooreActionHomeSetImpl();
    }

    @Override
    public MooreActionHomeSet emptySet(Comparator<? super MooreActionHome> comp) {
      return new MooreActionHomeSetImpl(comp);
    }

    @Override
    public MooreActionHomeSet value() {
        return this;
    }

    @Override
    public List<MooreActionHome> elements() {
        return Arrays.asList(toArray(new MooreActionHome[0]));
    }

}
